@@ -25,7 +25,7 @@ NameWidget::NameWidget(QWidget *parent)
 {
     auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins({});
-    auto label = new QLabel(i18n("Name"));
+    auto label = new QLabel(i18nc("@label:textbox", "Name"));
     label->setObjectName(QLatin1StringView("namelabel"));
     topLayout->addWidget(label);
 
@@ -39,7 +39,7 @@ NameWidget::NameWidget(QWidget *parent)
     setFocusPolicy(Qt::StrongFocus);
 
     mButtonEdit->setText(i18n("..."));
-    mButtonEdit->setToolTip(i18n("Edit Contact Name"));
+    mButtonEdit->setToolTip(i18nc("@info:tooltip", "Edit Contact Name"));
     lineLayout->addWidget(mButtonEdit);
 
     connect(mNameEdit, &QLineEdit::textChanged, this, &NameWidget::slotTextChanged);
